@@ -58,7 +58,7 @@ versions of L<IO::AIO> will be automatically wrapped as well.
 
 package Coro::AIO;
 
-use strict qw(subs vars);
+use common::sense;
 
 use IO::AIO 3.1 ();
 use AnyEvent::AIO ();
@@ -68,7 +68,7 @@ use Coro::AnyEvent ();
 
 use base Exporter::;
 
-our $VERSION = 5.17;
+our $VERSION = 5.2;
 
 our @EXPORT    = (@IO::AIO::EXPORT, qw(aio_wait));
 our @EXPORT_OK = @IO::AIO::EXPORT_OK;
