@@ -27,13 +27,12 @@ many coroutines as you want concurrently.
 
 package Coro::Channel;
 
-use strict qw(vars subs);
-no warnings;
+use common::sense;
 
 use Coro ();
 use Coro::Semaphore ();
 
-our $VERSION = 5.17;
+our $VERSION = 5.2;
 
 sub DATA (){ 0 }
 sub SGET (){ 1 }
