@@ -30,10 +30,9 @@ identifier.
 
 package Coro::SemaphoreSet;
 
-use strict qw(vars subs);
-no warnings;
+use common::sense;
 
-our $VERSION = 5.17;
+our $VERSION = 5.2;
 
 use Coro::Semaphore ();
 
