@@ -62,9 +62,7 @@ For listening sockets, use C<AnyEvent::Socket::tcp_server>.
 
 package Coro::Socket;
 
-no warnings "uninitialized";
-
-use strict;
+use common::sense;
 
 use Errno ();
 use Carp qw(croak);
@@ -75,7 +73,7 @@ use Coro::Util ();
 
 use base qw(Coro::Handle IO::Socket::INET);
 
-our $VERSION = 5.17;
+our $VERSION = 5.2;
 
 our (%_proto, %_port);
 
