@@ -70,8 +70,7 @@ rarely the need to do this yourself.
 
 package Coro::Storable;
 
-use strict qw(subs vars);
-no warnings;
+use common::sense;
 
 use Coro ();
 use Coro::Semaphore ();
@@ -85,7 +84,7 @@ BEGIN {
 use Storable;
 use base "Exporter";
 
-our $VERSION = 5.17;
+our $VERSION = 5.2;
 our @EXPORT = qw(thaw freeze nfreeze blocking_thaw blocking_freeze blocking_nfreeze);
 
 our $GRANULARITY = 0.01;
@@ -99,10 +98,10 @@ sub guard {
 # wrap xs functions
 for (qw(net_pstore pstore net_mstore mstore pretrieve mretrieve dclone)) {
    my $orig = \&{"Storable::$_"};
-   *{"Storable::$_"} = sub {
+   *{"Storable::$_"} = eval 'sub (' . (prototype $orig) . ') {
       my $guard = $lock->guard;
       &$orig
-   };
+   }';
    die if $@;
 }
 
